@@ -10,13 +10,17 @@ is not directly referenced by end users.
 from typing import Literal
 __all__ = ['api_prefix', 'argus_prefix', 'DATETIME_COL_FMT', 'DEPLOY_TYPE', 'EXPECTED_DELIVERY', 'WORK_ORDER_PRIORITY',
            'WORK_ORDER_STATUS', 'WORK_ORDER_CATEGORY', 'ERROR_TYPE', 'MAPPING_ENTITIES', 'QUEUE_NAME', 'QUERY_LANGUAGE',
-           'ACCOUNT', 'PROCESS_STATUS']
-#api_prefix = "http://localhost:7071/api/SwitchApi/"
+           'ACCOUNT', 'PROCESS_STATUS', 'AUTH_ENDPOINT_DEV', 'AUTH_ENDPOINT_PROD', 'SCHEDULE_TIMEZONE',
+           'SWITCH_ENVIRONMENT']
+
+# api_prefix = "http://localhost:7071/api/SwitchApi/"
 api_prefix = "https://pivotstreams.azurewebsites.net/api/SwitchApi/"
 
 # argus_prefix = "http://localhost:7071/api/"
 argus_prefix = "https://arguslogicv4b.azurewebsites.net/api/"
 
+AUTH_ENDPOINT_DEV = "https://restapi-dev.switchautomation.com/auth"
+AUTH_ENDPOINT_PROD = "https://restapi-us.switchautomation.com/auth"
 
 DATETIME_COL_FMT = Literal['DateTime', 'Date', 'Time']
 
@@ -25,26 +29,32 @@ DATETIME_COL_FMT = Literal['DateTime', 'Date', 'Time']
 #  'Split year and month in 2 columns',
 #  'Start and End Date in 2 columns']
 
-EXPECTED_DELIVERY = Literal['15min', 'Hourly', 'Daily', 'Monthly', 'Quarterly']
+EXPECTED_DELIVERY = Literal['15min', 'Hourly', 'Daily', 'Weekly', 'Monthly', 'Quarterly']
 
 DEPLOY_TYPE = Literal['ftp', 'email', 'timer']
 
-ACCOUNT = Literal['SwitchStorage', 'SwitchContainer', 'Argus']
+ACCOUNT = Literal['SwitchStorage', 'SwitchContainer', 'Argus', 'DataIngestion']
 
 QUERY_LANGUAGE = Literal['sql', 'kql']
 
 ERROR_TYPE = Literal['DateTime', 'MissingDevices', 'NonNumeric', 'MissingRequiredField(s)', 'MissingSite(s)',
-                     'DuplicateRecords', 'MissingSensors']
+                     'DuplicateRecords', 'MissingSensors', 'UnableToReadFile', 'InvalidFileType']
 
 PROCESS_STATUS = Literal['ActionRequired', 'Failed']
 
-MAPPING_ENTITIES = Literal['Installations', 'Devices/Sensors', 'Readings', 'Work Orders', 'Signals']
+MAPPING_ENTITIES = Literal['Installations', 'Devices/Sensors', 'Readings', 'Work Orders']
 
 WORK_ORDER_CATEGORY = Literal['Preventative Maintenance', 'Tenant Request']
 
 WORK_ORDER_PRIORITY = Literal['Low', 'Medium', 'High']
 
-WORK_ORDER_STATUS = Literal['Submitted', 'Open',  'In Progress', 'Waiting for 3rd Party', 'Resolved', 'Abandoned',
+WORK_ORDER_STATUS = Literal['Submitted', 'Open', 'In Progress', 'Waiting for 3rd Party', 'Resolved', 'Abandoned',
                             'Closed']
 
 QUEUE_NAME = Literal['task', 'highpriority']
+
+SCHEDULE_TIMEZONE = Literal['Local', 'Utc']
+
+SWITCH_ENVIRONMENT = Literal['Development', 'Staging', 'Testing', 'Production']
+
+SUPPORT_PAYLOAD_TYPE = Literal['Sites', 'Sensors', 'Portfolio']
