@@ -51,7 +51,7 @@ formatter = logging.Formatter('%(asctime)s  switch_api.%(module)s.%(funcName)s
 consoleHandler.setFormatter(formatter)
 
 
-def invalid_file_format(api_inputs: ApiInputs, schema: pandera.DataFrameSchema, raw_df: pandas.DataFrame):
+def invalid_file_format(api_inputs: ApiInputs, schema: pandera.DataFrameSchema, raw_df: pandas.DataFrame, process_status: PROCESS_STATUS = 'Failed'):
     """Validates the raw file format and posts any errors to data feed dashboard
 
     Parameters
@@ -69,21 +69,21 @@ def invalid_file_format(api_inputs: ApiInputs, schema: pandera.DataFrameSchema,
         Data frame containing the response from API after posting any errors to data feed dashboard.
 
     """
-    if api_inputs.datacentre == '' or api_inputs.api_key == '':
+    if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
-    headers = {
-        'x-functions-key': api_inputs.api_key,
-        'Content-Type': 'application/json; charset=utf-8',
-        'user-key': api_inputs.user_id
-    }
+    headers = api_inputs.api_headers.default
+
+    error_type = 'FileFormat'
 
     try:
         schema.validate(raw_df, lazy=True)
     except pandera.errors.SchemaErrors as err:
-        url = api_prefix + api_inputs.datacentre + "/" + api_inputs.api_project_id + "/DataFeedErrors/FileFormat"
+        url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/data-ingestion/data-feed/{api_inputs.data_feed_id}/errors?status={process_status}&errorType={error_type}&statusId={api_inputs.data_feed_id}"
+        logger.info("Sending request: POST %s", url)
         logger.error('Schema errors present: %s', err.failure_cases)
+
         schema_error = err.failure_cases
 
         response = requests.post(url, data=schema_error.to_json(orient='records'), headers=headers)
@@ -93,7 +93,7 @@ def invalid_file_format(api_inputs: ApiInputs, schema: pandera.DataFrameSchema,
                          response.reason)
             return response_status, pandas.DataFrame()
         elif len(response.text) == 0:
-            logger.error('No data returned for this API call. %s', response.request.__dict__)
+            logger.error('No data returned for this API call. %s', response.request.url)
             return response_status, pandas.DataFrame()
 
         response_data_frame = pandas.read_json(response.text)
@@ -118,16 +118,16 @@ def post_errors(api_inputs: ApiInputs, errors_df: pandas.DataFrame, error_type:
     process_status: PROCESS_STATUS, optional
         Set the status of the process to one of the allowed values specified by the PROCESS_STATUS literal
         (Default value = 'ActionRequired').
-        
+
     Returns
     -------
     response_boolean: boolean
         True or False indicating the success of the call
 
     """
-    if api_inputs.datacentre == '' or api_inputs.api_key == '':
+    if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
         logger.error("You must call initialize() before using API.")
-        return False
+        return pandas.DataFrame()
 
     if (api_inputs.data_feed_id == '00000000-0000-0000-0000-000000000000' or
             api_inputs.data_feed_file_status_id == '00000000-0000-0000-0000-000000000000'):
@@ -144,13 +144,10 @@ def post_errors(api_inputs: ApiInputs, errors_df: pandas.DataFrame, error_type:
                      'PROCESS_STATUS literal: %s', PROCESS_STATUS.__args__)
         return False
 
-    headers = {
-        'x-functions-key': api_inputs.api_key,
-        'Content-Type': 'application/json; charset=utf-8',
-        'user-key': api_inputs.user_id
-    }
-    url = api_prefix + api_inputs.datacentre + "/" + api_inputs.api_project_id + "/DataFeedErrors/" + str(error_type) \
-        + "/" + str(api_inputs.data_feed_id) + "/" + str(api_inputs.data_feed_file_status_id)
+    headers = api_inputs.api_headers.default
+
+    url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/data-ingestion/data-feed/{api_inputs.data_feed_id}/errors?status={process_status}&errorType={error_type}&statusId={api_inputs.data_feed_file_status_id}"
+    logger.info("Sending request: POST %s", url)
 
     response = requests.post(url,
                              data=json.dumps(json.loads(errors_df.to_json(orient='table'))['data']),
@@ -162,7 +159,7 @@ def post_errors(api_inputs: ApiInputs, errors_df: pandas.DataFrame, error_type:
                      response.reason)
         return response_status, False
     elif len(response.text) == 0:
-        logger.error('No data returned for this API call. %s', response.request.__dict__)
+        logger.error('No data returned for this API call. %s', response.request.url)
         return response_status, False
 
     logger.error(f'Directive:ProcessStatus={str(process_status)}')
