@@ -66,8 +66,8 @@ from abc import ABC, abstractmethod
 from azure.servicebus import ServiceBusClient, ServiceBusReceiveMode  # , ServiceBusMessage
 from .._utils._utils import _is_valid_regex, ApiInputs, generate_password, _column_name_cap, DataFeedFileProcessOutput
 from .._utils._constants import (api_prefix, argus_prefix, EXPECTED_DELIVERY, DEPLOY_TYPE, MAPPING_ENTITIES,
-                                 QUEUE_NAME, ERROR_TYPE)
-from .._utils._platform import _get_connection_string
+                                 QUEUE_NAME, ERROR_TYPE, SCHEDULE_TIMEZONE)
+from .._utils._platform import _get_ingestion_connection_string
 from io import StringIO
 
 logger = logging.getLogger(__name__)
@@ -220,15 +220,15 @@ class QueueTask(Task):
     @property
     @abstractmethod
     def maximum_message_count_per_call(self) -> int:
-        """ The maximum amount of messages which should be passed to the process_queue at any one time 
+        """ The maximum amount of messages which should be passed to the process_queue at any one time
             set to zero to consume all
         """
         pass
 
     @abstractmethod
     def start(self, api_inputs: ApiInputs):
-        """Method to be implemented if a file will be processed by the QueueTask Task.    
-        This will run once at the start of the processing and should contain     
+        """Method to be implemented if a file will be processed by the QueueTask Task.
+        This will run once at the start of the processing and should contain
 
         """
         pass
@@ -293,7 +293,7 @@ class Automation:
     @staticmethod
     def run_queue_task(task: QueueTask, api_inputs: ApiInputs, consume_all_messages: bool = False):
         """Runs a Queue Task when in Development Mode
-        
+
         The Queue Name should ideally be a testing Queue as messages will be consumed
 
         Parameters
@@ -312,9 +312,9 @@ class Automation:
 
         """
 
-        if api_inputs.datacentre == '' or api_inputs.api_key == '':
+        if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
             logger.error("You must call initialize() before using API.")
-            return False
+            return pandas.DataFrame()
 
         if not issubclass(type(task), QueueTask):
             logger.error(
@@ -327,8 +327,9 @@ class Automation:
         task.start(api_inputs)
 
         message_count = 0
-        with ServiceBusClient.from_connection_string(_get_connection_string(
-                api_inputs=api_inputs, account="Argus")) as client:
+
+        # TODO : Kate please review this - used new _get_ingestion_connection_string that only returns Data Ingestion Storage Connection String
+        with ServiceBusClient.from_connection_string(_get_ingestion_connection_string(api_inputs)) as client:
             with client.get_queue_receiver(task.queue_name,
                                            receive_mode=ServiceBusReceiveMode.RECEIVE_AND_DELETE) as receiver:
                 while True:
@@ -372,20 +373,17 @@ class Automation:
 
         """
 
-        if api_inputs.datacentre == '' or api_inputs.api_key == '':
+        if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
             logger.error("You must call initialize() before using API.")
             return pandas.DataFrame()
 
+        headers = api_inputs.api_headers.default
+
         logger.info("Reserving a testing instance for %s (%s) on Data Feed Id (%s). ", str(type(task).__name__),
                     str(task.id), str(data_feed_id))
 
-        headers = {
-            'x-functions-key': api_inputs.api_key,
-            'Content-Type': 'application/json; charset=utf-8',
-            'user-key': api_inputs.user_id
-        }
-
         url = argus_prefix + "ReserveInstance/" + str(data_feed_id) + "/" + str(minutes_to_reserve)
+        logger.info("Sending request: GET %s", url)
 
         response = requests.request("GET", url, timeout=20, headers=headers)
         response_status = '{} {}'.format(response.status_code, response.reason)
@@ -394,7 +392,7 @@ class Automation:
                          response.reason)
             return response_status, pandas.DataFrame()
         elif len(response.text) == 0:
-            logger.error('No data returned for this API call. %s', response.request.__dict__)
+            logger.error('No data returned for this API call. %s', response.request.url)
             return response_status, pandas.DataFrame()
 
         df = pandas.read_json(response.text, typ="Series")
@@ -402,13 +400,15 @@ class Automation:
         return df
 
     @staticmethod
-    def register_task(task):
+    def register_task(api_inputs: ApiInputs, task: Task):
         """Register the task.
 
         Registers the task that was defined.
 
         Parameters
         ----------
+        api_inputs : ApiInputs
+            Object returned by initialize() function.
         task : Task
             An instance of the custom class created from the Abstract Base Class `Task` or its abstract sub-classes:
             `IntegrationTask`, `AnalyticsTask`, `LogicModuleTask`.
@@ -431,8 +431,6 @@ class Automation:
             base_class = 'LogicModuleTask'
         elif issubclass(type(task), AnalyticsTask):
             base_class = 'AnalyticsTask'
-        elif issubclass(type(task), QueueTask):
-            base_class = 'QueueTask'
 
         if base_class == '':
             logger.error(
@@ -455,8 +453,16 @@ class Automation:
             "name": type(task).__name__
         }
 
-        url = api_prefix + "Automation/VerifyRegisterDriver"
-        response = requests.post(url, json=json_payload_verify)
+        if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
+            logger.error("You must call initialize() before using API.")
+            return pandas.DataFrame()
+
+        headers = api_inputs.api_headers.default
+
+        url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/data-ingestion/drivers/verification"
+        logger.info("Sending request: POST %s", url)
+
+        response = requests.post(url, json=json_payload_verify, headers=headers)
         response_status = '{} {}'.format(response.status_code, response.reason)
         if response.status_code != 200:
             logger.error("API Call was not successful. Response Status: %s. Reason: %s.", response.status_code,
@@ -475,16 +481,17 @@ class Automation:
             "baseClass": base_class
         }
 
-        url = api_prefix + "Automation/RegisterDriver"
+        url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/script-driver/registration"
+        logger.info("Sending request: POST %s", url)
 
-        response = requests.post(url, json=json_payload)
+        response = requests.post(url, json=json_payload, headers=headers)
         response_status = '{} {}'.format(response.status_code, response.reason)
         if response.status_code != 200:
             logger.error("API Call was not successful. Response Status: %s. Reason: %s.", response.status_code,
                          response.reason)
             return response_status, pandas.DataFrame()
         elif len(response.text) == 0:
-            logger.error('No data returned for this API call. %s', response.request.__dict__)
+            logger.error('No data returned for this API call. %s', response.request.url)
             return response_status, pandas.DataFrame()
 
         df = pandas.read_json(response.text)
@@ -510,17 +517,18 @@ class Automation:
             Dataframe containing the registered tasks.
 
         """
-        if api_inputs.datacentre == '' or api_inputs.api_key == '':
+        if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
             logger.error("You must call initialize() before using API.")
             return pandas.DataFrame()
 
-        headers = {
-            'x-functions-key': api_inputs.api_key,
-            'Content-Type': 'application/json; charset=utf-8',
-            'user-key': api_inputs.user_id
-        }
+        headers = api_inputs.api_headers.default
 
-        url = api_prefix + "Automation/ListDrivers/" + search_name_pattern
+        url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/data-ingestion/drivers"
+
+        if search_name_pattern != '*' and search_name_pattern != '':
+            url += f"?name={search_name_pattern}"
+
+        logger.info("Sending request: GET %s", url)
 
         response = requests.request("GET", url, timeout=20, headers=headers)
         response_status = '{} {}'.format(response.status_code, response.reason)
@@ -529,7 +537,7 @@ class Automation:
                          response.reason)
             return response_status, pandas.DataFrame()
         elif len(response.text) == 0:
-            logger.error('No data returned for this API call. %s', response.request.__dict__)
+            logger.error('No data returned for this API call. %s', response.request.url)
             return response_status, pandas.DataFrame()
 
         df = pandas.read_json(response.text)
@@ -541,7 +549,8 @@ class Automation:
     @staticmethod
     def deploy_as_email_data_feed(task, api_inputs: ApiInputs, expected_delivery: EXPECTED_DELIVERY,
                                   email_subject_regex: str, email_address_domain='switchautomation.com',
-                                  queue_name: QUEUE_NAME = 'task'):
+                                  queue_name: QUEUE_NAME = 'task',
+                                  data_feed_id: uuid.UUID = None):
         """Deploy task as an email data feed.
 
         Deploys the created `task` as an email data feed. This allows the driver to ingest data sent via email. The
@@ -563,6 +572,8 @@ class Automation:
             The email domain, without the @ symbol, of the sender (Default value = 'SwitchAutomation.com').
         queue_name : QUEUE_NAME, optional
             The name of queue (Default value = 'task').
+        data_feed_id : uuid.UUID, Optional
+            The DataFeedId to update if existing, else will create a new record with the given value.
 
         Returns
         -------
@@ -571,10 +582,15 @@ class Automation:
 
         """
 
-        if api_inputs.datacentre == '' or api_inputs.api_key == '':
+        if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
             logger.error("You must call initialize() before using API.")
             return pandas.DataFrame()
 
+        if data_feed_id is None:
+            data_feed_id = uuid.UUID('00000000-0000-0000-0000-000000000000')
+
+        headers = api_inputs.api_headers.default
+
         logger.info('Deploy %s (%s) as a data feed for ApiProjectID: %s', type(task).__name__, str(task.id),
                     api_inputs.api_project_id)
 
@@ -599,14 +615,9 @@ class Automation:
                          'QUEUE_NAME literal: %s', QUEUE_NAME.__args__)
             return pandas.DataFrame()
 
-        headers = {
-            'x-functions-key': api_inputs.api_key,
-            'Content-Type': 'application/json; charset=utf-8',
-            'user-key': api_inputs.user_id
-        }
-
         inbox_container = "data-exchange"
         payload = {
+            "dataFeedId": str(data_feed_id),
             "driverId": str(task.id),
             "name": 'Feed Settings for ' + type(task).__name__,
             "feedType": ",".join(task.mapping_entities),
@@ -620,7 +631,9 @@ class Automation:
             }
         }
 
-        url = api_prefix + api_inputs.datacentre + "/" + api_inputs.api_project_id + "/Automation/DeployTask"
+        url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/data-ingestion/tasks/deployment"
+
+        logger.info("Sending request: POST %s", url)
 
         response = requests.post(url, json=payload, headers=headers)
         response_status = '{} {}'.format(response.status_code, response.reason)
@@ -629,7 +642,7 @@ class Automation:
                          response.reason)
             return response_status, pandas.DataFrame()
         elif len(response.text) == 0:
-            logger.error('No data returned for this API call. %s', response.request.__dict__)
+            logger.error('No data returned for this API call. %s', response.request.url)
             return response_status, pandas.DataFrame()
 
         df = pandas.read_json(response.text, typ='Series').to_frame().T
@@ -639,7 +652,8 @@ class Automation:
 
     @staticmethod
     def deploy_as_ftp_data_feed(task, api_inputs: ApiInputs, ftp_user_name, ftp_password,
-                                expected_delivery: EXPECTED_DELIVERY, queue_name: QUEUE_NAME = 'task'):
+                                expected_delivery: EXPECTED_DELIVERY, queue_name: QUEUE_NAME = 'task',
+                                data_feed_id: uuid.UUID = None):
         """Deploy the custom driver as an FTP data feed
 
         Deploys the custom driver to receive data via an FTP data feed. Sets the `ftp_user_name` & `ftp_password` and
@@ -660,6 +674,8 @@ class Automation:
             The expected delivery frequency of the data.
         queue_name : QUEUE_NAME, default = 'task'
             The queue name (Default value = 'task').
+        data_feed_id : uuid.UUID, Optional
+            The DataFeedId to update if existing, else will create a new record with the given value.
 
         Returns
         -------
@@ -668,10 +684,15 @@ class Automation:
 
         """
 
-        if api_inputs.datacentre == '' or api_inputs.api_key == '':
+        if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
             logger.error("You must call initialize() before using API.")
             return pandas.DataFrame()
 
+        if data_feed_id is None:
+            data_feed_id = uuid.UUID('00000000-0000-0000-0000-000000000000')
+
+        headers = api_inputs.api_headers.default
+
         if not set([expected_delivery]).issubset(set(EXPECTED_DELIVERY.__args__)):
             logger.error('expected_delivery parameter must be set to one of the allowed values defined by the '
                          'EXPECTED_DELIVERY literal: %s', EXPECTED_DELIVERY.__args__)
@@ -685,14 +706,9 @@ class Automation:
         logger.info('Deploy %s (%s) as a data feed for ApiProjectID: %s', type(task).__name__, str(task.id),
                     api_inputs.api_project_id)
 
-        headers = {
-            'x-functions-key': api_inputs.api_key,
-            'Content-Type': 'application/json; charset=utf-8',
-            'user-key': api_inputs.user_id
-        }
-
         inbox_container = "data-exchange"
         payload = {
+            "dataFeedId": str(data_feed_id),
             "driverId": str(task.id),
             "name": 'Feed Settings for ' + type(task).__name__,
             "feedType": ",".join(task.mapping_entities),
@@ -706,7 +722,9 @@ class Automation:
             }
         }
 
-        url = api_prefix + api_inputs.datacentre + "/" + api_inputs.api_project_id + "/Automation/DeployTask"
+        url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/data-ingestion/tasks/deployment"
+
+        logger.info("Sending request: POST %s", url)
 
         response = requests.post(url, json=payload, headers=headers)
         response_status = '{} {}'.format(response.status_code, response.reason)
@@ -715,7 +733,7 @@ class Automation:
                          response.reason)
             return response_status, pandas.DataFrame()
         elif len(response.text) == 0:
-            logger.error('No data returned for this API call. %s', response.request.__dict__)
+            logger.error('No data returned for this API call. %s', response.request.url)
             return response_status, pandas.DataFrame()
 
         df = pandas.read_json(response.text, typ='Series').to_frame().T
@@ -725,9 +743,27 @@ class Automation:
 
     @staticmethod
     def deploy_as_upload_data_feed(task, api_inputs: ApiInputs, expected_delivery: EXPECTED_DELIVERY,
-                                   queue_name: QUEUE_NAME = 'task'):
+                                   queue_name: QUEUE_NAME = 'task',
+                                   data_feed_id: uuid.UUID = None):
         """Deploy the custom driver as a REST API end point Datafeed.
 
+        To upload a file to the deployed data feed, use the UploadUrl from the response dataframe (with request type
+        POST) with the following two headers:
+
+        - 'Ocp-Apim-Subscription-Key' - set to the value of ``api_inputs.subscription_key``
+        - 'Authorization' - set to the value 'Bearer ``api_inputs.bearer_token``'
+
+        For example, to upload a file using the ``requests`` package:
+
+        >>> import requests
+        >>> url = df.loc[0,'UploadUrl']
+        >>> payload={}
+        >>> file_path = 'C:/xxyyzz.txt'
+        >>> files={'file': open(file_path, 'rb')}
+        >>> headers = {'Ocp-Apim-Subscription-Key': api_inputs.subscription_key, 'Authorization': f'Bearer {api_inputs.bearer_token}'}
+        >>> response = requests.request("POST", url, headers=headers, data=payload, files=files)
+        >>> print(response.text)
+
         Parameters
         ----------
         task : Task
@@ -738,7 +774,8 @@ class Automation:
             The expected delivery frequency of the data.
         queue_name : QUEUE_NAME, optional
             The queue name (Default value = 'task').
-
+        data_feed_id : uuid.UUID, Optional
+            The DataFeedId to update if existing, else will create a new record with the given value.
 
         Returns
         -------
@@ -747,10 +784,15 @@ class Automation:
 
         """
 
-        if api_inputs.datacentre == '' or api_inputs.api_key == '':
+        if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
             logger.error("You must call initialize() before using API.")
             return pandas.DataFrame()
 
+        if data_feed_id is None:
+            data_feed_id = uuid.UUID('00000000-0000-0000-0000-000000000000')
+
+        headers = api_inputs.api_headers.default
+
         if not set([expected_delivery]).issubset(set(EXPECTED_DELIVERY.__args__)):
             logger.error('expected_delivery parameter must be set to one of the allowed values defined by the '
                          'EXPECTED_DELIVERY literal: %s', EXPECTED_DELIVERY.__args__)
@@ -764,14 +806,8 @@ class Automation:
         logger.info('Deploy %s (%s) as a data feed for ApiProjectID: %s', type(task).__name__, str(task.id),
                     api_inputs.api_project_id)
 
-        headers = {
-            'x-functions-key': api_inputs.api_key,
-            'Content-Type': 'application/json; charset=utf-8',
-            'user-key': api_inputs.user_id
-        }
-
-        # inbox_container = "data-exchange"
         payload = {
+            "dataFeedId": str(data_feed_id),
             "driverId": str(task.id),
             "name": 'Feed Settings for ' + type(task).__name__,
             "feedType": ",".join(task.mapping_entities),
@@ -783,7 +819,9 @@ class Automation:
             },
         }
 
-        url = api_prefix + api_inputs.datacentre + "/" + api_inputs.api_project_id + "/Automation/DeployTask"
+        url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/data-ingestion/tasks/deployment"
+
+        logger.info("Sending request: POST %s", url)
 
         response = requests.post(url, json=payload, headers=headers)
         response_status = '{} {}'.format(response.status_code, response.reason)
@@ -792,7 +830,7 @@ class Automation:
                          response.reason)
             return response_status, pandas.DataFrame()
         elif len(response.text) == 0:
-            logger.error('No data returned for this API call. %s', response.request.__dict__)
+            logger.error('No data returned for this API call. %s', response.request.url)
             return response_status, pandas.DataFrame()
 
         df = pandas.read_json(StringIO(response.text), typ='Series').to_frame().T
@@ -800,9 +838,13 @@ class Automation:
 
         return df
 
+    # TODO: PLease review Kate. Added timezone_offset_minutes with a default of 0. This is being checked in the API but if none defaults to 0
+    # TODO: PLease review Kate. Added schedule_timezone with a default of Utc. This is being checked in the API
     @staticmethod
-    def deploy_on_timer(task, api_inputs: ApiInputs, cron_schedule, expected_delivery: EXPECTED_DELIVERY,
-                        queue_name: QUEUE_NAME = "task", settings: dict = None):
+    def deploy_on_timer(task, api_inputs: ApiInputs, cron_schedule: str, expected_delivery: EXPECTED_DELIVERY,
+                        queue_name: QUEUE_NAME = "task", settings: dict = None,
+                        schedule_timezone: SCHEDULE_TIMEZONE = 'Local', timezone_offset_minutes: int = None,
+                        data_feed_id: uuid.UUID = None):
         """Deploy driver to run on timer.
 
         Parameters
@@ -811,15 +853,23 @@ class Automation:
             The custom driver class created from the Abstract Base Class `Driver`.
         api_inputs : ApiInputs
             Object returned by initialize.initialize() function
-        cron_schedule :
-            Cron object containing the required schedule for the driver to be run.
+        cron_schedule : str
+            The CRONOS cron object containing the required schedule for the driver to be run. For details on the
+            required format, see: https://crontab.cronhub.io/
         expected_delivery : EXPECTED_DELIVERY
             The expected delivery frequency.
         queue_name : QUEUE_NAME, optional
             The queue name (Default value = 'task').
         settings : dict, Optional
-                List of settings used to deploy the driver. For example, may contain the user_name and password
-                required to authenticate calls to a third-party API (Default value = None).
+            List of settings used to deploy the driver. For example, may contain the user_name and password required to
+            authenticate calls to a third-party API (Default value = None).
+        schedule_timezone : SCHEDULE_TIMEZONE, optional
+            Whether the ``cron_schedule`` should be applied based on Local or Utc timezone. If set to `Local`, this is
+            taken as the timezone of the western-most site in the given portfolio (Default value = 'Local').
+        timezone_offset_minutes: int, Optional
+            Timezone offset in minutes (from UTC) to be used when applying the ``cron_schedule`` (Default value = None).
+        data_feed_id : uuid.UUID, Optional
+            The DataFeedId to update if existing, else will create a new record with the given value.
 
         Returns
         -------
@@ -828,22 +878,35 @@ class Automation:
 
         """
 
-        if api_inputs.datacentre == '' or api_inputs.api_key == '':
+        if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
             logger.error("You must call initialize() before using API.")
             return pandas.DataFrame()
 
+        if data_feed_id is None:
+            data_feed_id = uuid.UUID('00000000-0000-0000-0000-000000000000')
+
+        if timezone_offset_minutes is None:
+            timezone_offset_minutes = 0
+
+        headers = api_inputs.api_headers.default
+
         if not set([expected_delivery]).issubset(set(EXPECTED_DELIVERY.__args__)):
             logger.error('expected_delivery parameter must be set to one of the allowed values defined by the '
                          'EXPECTED_DELIVERY literal: %s', EXPECTED_DELIVERY.__args__)
             return pandas.DataFrame()
 
+        if not set([schedule_timezone]).issubset(set(SCHEDULE_TIMEZONE.__args__)):
+            logger.error('schedule_timezone parameter must be set to one of the allowed values defined by the '
+                         'SCHEDULE_TIMEZONE literal: %s', SCHEDULE_TIMEZONE.__args__)
+            return pandas.DataFrame()
+
         if not set([queue_name]).issubset(set(QUEUE_NAME.__args__)):
             logger.error('queue_name parameter must be set to one of the allowed values defined by the '
                          'QUEUE_NAME literal: %s', QUEUE_NAME.__args__)
             return pandas.DataFrame()
 
-        if len(cron_schedule.split(' ')) != 7:
-            logger.error("cron_schedule parameter must be in the format * * * * * *")
+        if len(cron_schedule.split(' ')) < 5 and len(cron_schedule.split(' ')) > 6:
+            logger.error("cron_schedule parameter must be in the format * * * * *")
             return pandas.DataFrame()
 
         # # TODO - discuss whether this is required since we added the Literal EXPECTED_DELIVERY
@@ -862,26 +925,25 @@ class Automation:
         logger.info('Feed Type is %s', str(task.mapping_entities))
         logger.info('Settings to be passed to the driver on start are: %s', str(settings))
 
-        headers = {
-            'x-functions-key': api_inputs.api_key,
-            'Content-Type': 'application/json; charset=utf-8',
-            'user-key': api_inputs.user_id
-        }
-
         payload = {
+            "dataFeedId": str(data_feed_id),
             "driverId": str(task.id),
             "name": 'Timer Settings for ' + type(task).__name__,
             "feedType": ",".join(task.mapping_entities),
             "expectedDelivery": expected_delivery,
-            "sourceType": "BlobFolder",
+            "sourceType": "Timer",
             "queueName": queue_name,
             "timer": {
-                "cronSchedule": cron_schedule
+                "cronSchedule": cron_schedule,
+                "timezoneOffsetMinutes": timezone_offset_minutes,
+                "scheduleTimezone": schedule_timezone
             },
             "settings": settings
         }
 
-        url = api_prefix + api_inputs.datacentre + "/" + api_inputs.api_project_id + "/Automation/DeployTask"
+        url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/data-ingestion/tasks/deployment"
+
+        logger.info("Sending request: POST %s", url)
 
         response = requests.post(url, json=payload, headers=headers)
         response_status = '{} {}'.format(response.status_code, response.reason)
@@ -890,7 +952,7 @@ class Automation:
                          response.reason)
             return response_status, pandas.DataFrame()
         elif len(response.text) == 0:
-            logger.error('No data returned for this API call. %s', response.request.__dict__)
+            logger.error('No data returned for this API call. %s', response.request.url)
             return response_status, pandas.DataFrame()
 
         df = pandas.read_json(response.text, typ='Series').to_frame().T
@@ -899,17 +961,15 @@ class Automation:
         return df
 
     @staticmethod
-    def cancel_deploy(task, api_inputs: ApiInputs, deploy_type: DEPLOY_TYPE = 'timer'):
+    def cancel_deployed_timer(api_inputs: ApiInputs, data_feed_id: uuid.UUID):
         """Deploy driver to run on timer.
 
         Parameters
         ----------
-        task : Task
-            The custom task class created from the Abstract Base Class `Task`.
         api_inputs : ApiInputs
             Object returned by initialize.initialize() function
-        deploy_type : DEPLOY_TYPE, optional
-            One of the deploy types defined by the DEPLOY_TYPE literal (Default value = 'timer')
+        data_feed_id: uuid.UUID, Required
+            Datafeed Id to cancel deployment
 
 
         Returns
@@ -919,42 +979,31 @@ class Automation:
 
         """
 
-        if api_inputs.datacentre == '' or api_inputs.api_key == '':
+        if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
             logger.error("You must call initialize() before using API.")
             return pandas.DataFrame()
 
-        if str(deploy_type) != 'timer':
-            logger.error('The cancel_deploy() function currently only works for data feeds deployed on timer. ')
+        headers = api_inputs.api_headers.default
+
+        # TODO: Please review Kate. Removed checking of Deployment Type of Timer and added required parameter of Data Feed Id
+        if (data_feed_id == None):
+            logger.error('Data feed Id cannot be None')
             return
 
-        if not set([deploy_type]).issubset(set(DEPLOY_TYPE.__args__)):
-            logger.error('deploy_type parameter must be set to one of the allowed values defined by the '
-                         'DEPLOY_TYPE literal: %s', DEPLOY_TYPE.__args__)
-            return pandas.DataFrame()
+        url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/data-ingestion/deployment/{data_feed_id}/cancel"
 
-        logger.info('Cancel deploy %s (%s) on timer for ApiProjectID: %s', type(task).__name__,
-                    str(task.id), api_inputs.api_project_id)
-        logger.info('Feed Type is %s', str(task.mapping_entities))
+        logger.info("Cancel deploy with DataFeedID: %s for ApiProjectID: %s", data_feed_id, api_inputs.api_project_id)
+        logger.info("Sending request: POST %s", url)
 
-        headers = {
-            'x-functions-key': api_inputs.api_key,
-            'Content-Type': 'application/json; charset=utf-8',
-            'user-key': api_inputs.user_id
-        }
-
-        # payload = {}
-
-        url = api_prefix + api_inputs.datacentre + "/" + api_inputs.api_project_id + "/Automation/CancelTask/" + \
-            deploy_type + "/" + str(task.id)
-
-        response = requests.get(url, headers=headers)
+        # TODO: Please review Kate. Changed method to POST instead of GET, to align with API
+        response = requests.post(url, headers=headers)
         response_status = '{} {}'.format(response.status_code, response.reason)
         if response.status_code != 200:
             logger.error("API Call was not successful. Response Status: %s. Reason: %s.", response.status_code,
                          response.reason)
             return response_status, pandas.DataFrame()
         elif len(response.text) == 0:
-            logger.error('No data returned for this API call. %s', response.request.__dict__)
+            logger.error('No data returned for this API call. %s', response.request.url)
             return response_status, pandas.DataFrame()
 
         df = pandas.read_json(response.text, typ='Series').to_frame().T
@@ -981,18 +1030,18 @@ class Automation:
 
         """
 
-        if api_inputs.datacentre == '' or api_inputs.api_key == '':
+        if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
             logger.error("You must call initialize() before using API.")
             return pandas.DataFrame()
 
-        headers = {
-            'x-functions-key': api_inputs.api_key,
-            'Content-Type': 'application/json; charset=utf-8',
-            'user-key': api_inputs.user_id
-        }
+        headers = api_inputs.api_headers.default
 
-        url = api_prefix + api_inputs.datacentre + "/" + api_inputs.api_project_id + "/Automation/ListDeployments/" + \
-            search_name_pattern
+        url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/data-ingestion/data-feed/search"
+
+        if search_name_pattern != '' and search_name_pattern != '*':
+            url += f"?name={search_name_pattern}"
+
+        logger.info("Sending request: GET %s", url)
 
         response = requests.request("GET", url, timeout=20, headers=headers)
         response_status = '{} {}'.format(response.status_code, response.reason)
@@ -1001,7 +1050,7 @@ class Automation:
                          response.reason)
             return response_status, pandas.DataFrame()
         elif len(response.text) == 0:
-            logger.error('No data returned for this API call. %s', response.request.__dict__)
+            logger.error('No data returned for this API call. %s', response.request.url)
             return response_status, pandas.DataFrame()
 
         df = pandas.read_json(response.text)
@@ -1034,14 +1083,15 @@ class Automation:
             logger.error('The data_feed_id parameter must be provided. ')
             return
 
-        headers = {
-            'x-functions-key': api_inputs.api_key,
-            'Content-Type': 'application/json; charset=utf-8',
-            'user-key': api_inputs.user_id
-        }
+        if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
+            logger.error("You must call initialize() before using API.")
+            return pandas.DataFrame()
 
-        url = api_prefix + api_inputs.datacentre + "/" + api_inputs.api_project_id + \
-            "/Automation/ListDataFeedsHistory/" + str(data_feed_id) + "/" + str(top_count)
+        headers = api_inputs.api_headers.default
+
+        url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/data-ingestion/data-feed/{data_feed_id}/history?topCount={top_count}"
+
+        logger.info("Sending request: GET %s", url)
 
         response = requests.request("GET", url, timeout=20, headers=headers)
 
@@ -1051,7 +1101,7 @@ class Automation:
                          response.reason)
             return response_status, pandas.DataFrame()
         elif len(response.text) == 0:
-            logger.error('No data returned for this API call. %s', response.request.__dict__)
+            logger.error('No data returned for this API call. %s', response.request.url)
             return response_status, pandas.DataFrame()
 
         df = pandas.read_json(response.text)
@@ -1112,15 +1162,14 @@ class Automation:
         if data_feed_file_status_id is None:
             data_feed_file_status_id = '00000000-0000-0000-0000-000000000000'
 
-        headers = {
-            'x-functions-key': api_inputs.api_key,
-            'Content-Type': 'application/json; charset=utf-8',
-            'user-key': api_inputs.user_id
-        }
+        if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
+            logger.error("You must call initialize() before using API.")
+            return pandas.DataFrame()
 
-        url = api_prefix + api_inputs.datacentre + "/" + api_inputs.api_project_id + \
-            "/Automation/DataFeedsProcessOutput/" + str(data_feed_id) + "/" + str(data_feed_file_status_id) + "/" + \
-            str(row_number)
+        headers = api_inputs.api_headers.default
+
+        url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/data-ingestion/data-feed/{data_feed_id}/file-status/{data_feed_file_status_id}/process-output?rowCount={row_number}"
+        logger.info("Sending request: GET %s", url)
 
         response = requests.request("GET", url, timeout=20, headers=headers)
 
@@ -1130,7 +1179,7 @@ class Automation:
                          response.reason)
             return response_status, pandas.DataFrame()
         elif len(response.text) == 0:
-            logger.error('No data returned for this API call. %s', response.request.__dict__)
+            logger.error('No data returned for this API call. %s', response.request.url)
             return response_status, pandas.DataFrame()
 
         data_feed_file_process_output = json.loads(response.text, object_hook=lambda d: DataFeedFileProcessOutput(
@@ -1171,14 +1220,14 @@ class Automation:
             logger.error('The data_feed_id and data_feed_file_status_id parameters must be provided. ')
             return
 
-        headers = {
-            'x-functions-key': api_inputs.api_key,
-            'Content-Type': 'application/json; charset=utf-8',
-            'user-key': api_inputs.user_id
-        }
+        if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
+            logger.error("You must call initialize() before using API.")
+            return pandas.DataFrame()
 
-        url = api_prefix + api_inputs.datacentre + "/" + api_inputs.api_project_id + \
-            "/Automation/DataFeedsProcessErrors/" + str(data_feed_id) + "/" + str(data_feed_file_status_id)
+        headers = api_inputs.api_headers.default
+
+        url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/data-ingestion/data-feed/{data_feed_id}/file-status/{data_feed_file_status_id}/process-errors"
+        logger.info("Sending request: GET %s", url)
 
         response = requests.request("GET", url, timeout=20, headers=headers)
 
@@ -1188,7 +1237,7 @@ class Automation:
                          response.reason)
             return response_status, pandas.DataFrame()
         elif len(response.text) == 0:
-            logger.error('No data returned for this API call. %s', response.request.__dict__)
+            logger.error('No data returned for this API call. %s', response.request.url)
             return response_status, pandas.DataFrame()
 
         df = pandas.read_json(response.text)
@@ -1231,15 +1280,11 @@ class Automation:
                          'ERROR_TYPE literal: %s', ERROR_TYPE.__args__)
             return pandas.DataFrame()
 
-        headers = {
-            'x-functions-key': api_inputs.api_key,
-            'Content-Type': 'application/json; charset=utf-8',
-            'user-key': api_inputs.user_id
-        }
+        headers = api_inputs.api_headers.default
 
-        url = api_prefix + api_inputs.datacentre + "/" + api_inputs.api_project_id + \
-            "/Automation/DataFeedsProcessGetErrorsByType/" + str(data_feed_id) + "/" + str(data_feed_file_status_id) \
-            + "/" + str(error_type)
+        url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/data-ingestion/data-feed/{data_feed_id}/file-status/{data_feed_file_status_id}/process-errors/type/{error_type}"
+
+        logger.info("Sending request: GET %s", url)
 
         response = requests.request("GET", url, timeout=20, headers=headers)
 
@@ -1249,10 +1294,10 @@ class Automation:
                          response.reason)
             return response_status, pandas.DataFrame()
         elif len(response.text) == 0:
-            logger.error('No data returned for this API call. %s', response.request.__dict__)
+            logger.error('No data returned for this API call. %s', response.request.url)
             return response_status, pandas.DataFrame()
 
-        df = pandas.read_csv(StringIO(response.text), sep=",", error_bad_lines=False)
+        df = pandas.read_csv(StringIO(response.text), sep=",")  # , error_bad_lines=False)
         return df
 
     @staticmethod
